CommandUtf8Ext

Trait CommandUtf8Ext 

pub trait CommandUtf8Ext {
    // Required method
    fn set_c_locale(&mut self);
}
A trait for setting the locale of a subprocess to C.

Required Methods

fn set_c_locale(&mut self)

Ensure that a child subprocess runs with the C locale (Unix only).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CommandUtf8Ext for Command

Source

fn set_c_locale(&mut self)

Implementors